@@ -1,4 +1,5 @@
-/* Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009 Bart Hakvoort
+/* Copyright (C) 2004 Bart
+ * Copyright (C) 2008, 2009 Curtis Gedak
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -53,7 +54,7 @@ Dialog_Base_Partition::Dialog_Base_Partition()
 	
 	//add spinbutton_before
 	table_resize .attach(
-		* Utils::mk_label( static_cast<Glib::ustring>( _( "Free Space Preceding (MiB):") ) + " \t" ),
+		* Utils::mk_label( static_cast<Glib::ustring>( _( "Free space preceding (MiB):") ) + " \t" ),
 		0, 1, 0, 1,
 		Gtk::SHRINK );
 		
@@ -62,14 +63,14 @@ Dialog_Base_Partition::Dialog_Base_Partition()
 	table_resize.attach( spinbutton_before, 1, 2, 0, 1, Gtk::FILL );
 	
 	//add spinbutton_size
-	table_resize.attach( * Utils::mk_label( _( "New Size (MiB):" ) ), 0, 1, 1, 2 );
+	table_resize.attach( * Utils::mk_label( _( "New size (MiB):" ) ), 0, 1, 1, 2 );
 
 	spinbutton_size .set_numeric( true );
 	spinbutton_size .set_increments( 1, 100 );
 	table_resize.attach( spinbutton_size, 1, 2, 1, 2, Gtk::FILL );
 	
 	//add spinbutton_after
-	table_resize.attach( * Utils::mk_label( _( "Free Space Following (MiB):") ), 0, 1, 2, 3 ) ;
+	table_resize.attach( * Utils::mk_label( _( "Free space following (MiB):") ), 0, 1, 2, 3 ) ;
 	
 	spinbutton_after .set_numeric( true );
 	spinbutton_after .set_increments( 1, 100 );
@@ -187,8 +188,8 @@ void Dialog_Base_Partition::Set_Confirm_Button( CONFIRMBUTTON button_type )
 
 void Dialog_Base_Partition::Set_MinMax_Text( Sector min, Sector max )
 {
-	str_temp = String::ucompose( _("Minimum Size: %1 MiB"), min ) + "\t\t" ;
-	str_temp += String::ucompose( _("Maximum Size: %1 MiB"), max ) ;
+	str_temp = String::ucompose( _("Minimum size: %1 MiB"), min ) + "\t\t" ;
+	str_temp += String::ucompose( _("Maximum size: %1 MiB"), max ) ;
 	label_minmax .set_text( str_temp ) ; 
 }
 
