@@ -1,4 +1,5 @@
-/* Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009 Bart Hakvoort
+/* Copyright (C) 2004 Bart
+ * Copyright (C) 2008, 2009 Curtis Gedak
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -108,7 +109,7 @@ void Dialog_Partition_New::Set_Data( const Partition & partition,
 	table_create .attach( optionmenu_type, 1, 2, 0, 1, Gtk::FILL );
 	
 	//file systems to choose from 
-	table_create .attach( * Utils::mk_label( static_cast<Glib::ustring>( _("File System:") ) + "\t" ),
+	table_create .attach( * Utils::mk_label( static_cast<Glib::ustring>( _("File system:") ) + "\t" ),
 			     0, 1, 1, 2,
 			     Gtk::FILL );
 	
