@@ -1,5 +1,5 @@
 /* Copyright (C) 2004 Bart 'plors' Hakvoort
- * Copyright (C) 2008, 2009 Curtis Gedak
+ * Copyright (C) 2008, 2009, 2010 Curtis Gedak
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -246,9 +246,19 @@ void GParted_Core::set_devices( std::vector<Device> & devices )
 				set_thread_status_message( String::ucompose ( _("Confirming %1"), lp_device ->path ) ) ;
 				if ( ped_device_open( lp_device ) )
 				{
-					if ( ped_device_read( lp_device, buf, 0, 1 ) )
-						device_paths .push_back( lp_device ->path ) ;
-
+					//FIXME: Remove this check when both GParted and libparted
+					//       support devices with a logical sector size != 512.
+					if ( lp_device ->sector_size != 512 )
+					{
+						/*TO TRANSLATORS: looks like  Ignoring device /dev/sde with logical sector size of 2048 bytes because gparted only supports a size of 512 bytes. */
+						Glib::ustring msg = String::ucompose ( _("Ignoring device %1 with logical sector size of %2 bytes because gparted only supports a size of 512 bytes."), lp_device ->path, lp_device ->sector_size ) ;
+						std::cout << msg << std::endl << std::endl ;
+					}
+					else
+					{
+						if ( ped_device_read( lp_device, buf, 0, 1 ) )
+							device_paths .push_back( lp_device ->path ) ;
+					}
 					ped_device_close( lp_device ) ;
 				}
 				free( buf ) ;
@@ -2749,7 +2759,7 @@ void GParted_Core::close_device_and_disk()
 bool GParted_Core::commit() 
 {
 	bool succes = ped_disk_commit_to_dev( lp_disk ) ;
-
+	
 	succes = commit_to_os( 10 ) && succes ;
 
 	return succes ;
@@ -2762,8 +2772,19 @@ bool GParted_Core::commit_to_os( std::time_t timeout )
 	if ( dmraid .is_dmraid_device( lp_disk ->dev ->path ) )
 		succes = true ;
 	else
+	{
 		succes = ped_disk_commit_to_os( lp_disk ) ;
 
+		//FIXME:  Work around to try to alleviate problems caused by
+		//  bug #604298 - Failure to inform kernel of partition changes
+		//  If not successful the first time, try one more time.
+		if ( ! succes )
+		{
+			sleep( 1 ) ;
+			succes = ped_disk_commit_to_os( lp_disk ) ;
+		}
+	}
+
 	settle_device( timeout ) ;
 
 	return succes ;
