@@ -1,4 +1,5 @@
-/* Copyright (C) 2004, 2005, 2006, 2007, 2008 Bart Hakvoort
+/* Copyright (C) 2004 Bart 'plors' Hakvoort
+ * Copyright (C) 2008, 2009, 2010 Curtis Gedak
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -14,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
- 
+
 #include "../include/Utils.h"
 
 #include <sstream>
@@ -22,9 +23,10 @@
 #include <regex.h>
 #include <locale.h>
 
+
 namespace GParted
 {
-	
+
 Sector Utils::round( double double_value )
 {
 	 return static_cast<Sector>( double_value + 0.5 ) ;
@@ -35,61 +37,66 @@ Gtk::Label * Utils::mk_label( const Glib::ustring & text,
 			      Gtk::AlignmentEnum x_align,
 			      Gtk::AlignmentEnum y_align,
 			      bool wrap,
-			      const Glib::ustring & text_color ) 
+			      bool selectable,
+			      const Glib::ustring & text_color )
 {
 
 	Gtk::Label * label = manage( new Gtk::Label( text, x_align, y_align ) ) ;
-	
+
 	label ->set_use_markup( use_markup ) ;
 	label ->set_line_wrap( wrap ) ;
-	
+	label ->set_selectable( selectable ) ;
+
 	if ( text_color != "black" )
 	{
 		Gdk::Color color( text_color ) ;
 		label ->modify_fg( label ->get_state(), color ) ;
 	}
-	
+
 	return label ;
 }
 
-Glib::ustring Utils::num_to_str( Sector number, bool use_C_locale )
+Glib::ustring Utils::num_to_str( Sector number )
 {
 	std::stringstream ss ;
-	//ss.imbue( std::locale( use_C_locale ? "C" : "" ) ) ; see #157871
 	ss << number ;
 	return ss .str() ;
 }
 
 //use http://developer.gnome.org/projects/gup/hig/2.0/design.html#Palette as a starting point..
-Glib::ustring Utils::get_color( FILESYSTEM filesystem ) 
-{ 
+Glib::ustring Utils::get_color( FILESYSTEM filesystem )
+{
 	switch( filesystem )
 	{
-		case FS_UNALLOCATED	: return "#A9A9A9" ;
-		case FS_UNKNOWN		: return "#000000" ;
-		case FS_UNFORMATTED	: return "#000000" ;
-		case FS_EXTENDED	: return "#7DFCFE" ;
-		case FS_EXT2		: return "#9DB8D2" ;
-		case FS_EXT3		: return "#7590AE" ;
-		case FS_LINUX_SWAP	: return "#C1665A" ;
-		case FS_FAT16		: return "#00FF00" ;
-		case FS_FAT32		: return "#18D918" ;
-		case FS_NTFS		: return "#42E5AC" ;
-		case FS_REISERFS	: return "#ADA7C8" ;
-		case FS_REISER4		: return "#887FA3" ;
-		case FS_XFS		: return "#EED680" ;
-		case FS_JFS		: return "#E0C39E" ;
-		case FS_HFS		: return "#E0B6AF" ;
-		case FS_HFSPLUS		: return "#C0A39E" ;
-		case FS_UFS		: return "#D1940C" ;
-		case FS_USED		: return "#F8F8BA" ;
-		case FS_UNUSED		: return "#FFFFFF" ;
+		case FS_UNALLOCATED	: return "#A9A9A9" ;	// ~ medium grey
+		case FS_UNKNOWN		: return "#000000" ;	//black
+		case FS_UNFORMATTED	: return "#000000" ;	//black
+		case FS_EXTENDED	: return "#7DFCFE" ;	// ~ light blue
+		case FS_BTRFS		: return "#FF9955" ;	//orange
+		case FS_EXT2		: return "#9DB8D2" ;	//blue hilight
+		case FS_EXT3		: return "#7590AE" ;	//blue medium
+		case FS_EXT4		: return "#4B6983" ;	//blue dark
+		case FS_LINUX_SWAP	: return "#C1665A" ;	//red medium
+		case FS_FAT16		: return "#00FF00" ;	//green
+		case FS_FAT32		: return "#18D918" ;	// ~ medium green
+		case FS_NTFS		: return "#42E5AC" ;	// ~ light turquoise
+		case FS_REISERFS	: return "#ADA7C8" ;	//purple hilight
+		case FS_REISER4		: return "#887FA3" ;	//purple medium
+		case FS_XFS			: return "#EED680" ;	//accent yellow
+		case FS_JFS			: return "#E0C39E" ;	//face skin medium
+		case FS_HFS			: return "#E0B6AF" ;	//red hilight
+		case FS_HFSPLUS		: return "#C0A39E" ;	// ~ serene red
+		case FS_UFS			: return "#D1940C" ;	//accent yellow dark
+		case FS_USED		: return "#F8F8BA" ;	// ~ light tan yellow
+		case FS_UNUSED		: return "#FFFFFF" ;	//white
+		case FS_LVM2		: return "#CC9966" ;	// ~ medium brown
+		case FS_LUKS		: return "#625B81" ;	//purple dark
 
-		default			: return "#000000" ;
+		default				: return "#000000" ;
 	}
 }
 
-Glib::RefPtr<Gdk::Pixbuf> Utils::get_color_as_pixbuf( FILESYSTEM filesystem, int width, int height ) 
+Glib::RefPtr<Gdk::Pixbuf> Utils::get_color_as_pixbuf( FILESYSTEM filesystem, int width, int height )
 {
 	Glib::RefPtr<Gdk::Pixbuf> pixbuf = Gdk::Pixbuf::create( Gdk::COLORSPACE_RGB, false, 8, width, height ) ;
 
@@ -109,12 +116,14 @@ Glib::ustring Utils::get_filesystem_string( FILESYSTEM filesystem )
 {
 	switch( filesystem )
 	{
-		case FS_UNALLOCATED	: return _("unallocated") ; 
+		case FS_UNALLOCATED	: return _("unallocated") ;
 		case FS_UNKNOWN		: return _("unknown") ;
 		case FS_UNFORMATTED	: return _("unformatted") ;
 		case FS_EXTENDED	: return "extended" ;
+		case FS_BTRFS		: return "btrfs" ;
 		case FS_EXT2		: return "ext2" ;
 		case FS_EXT3		: return "ext3" ;
+		case FS_EXT4		: return "ext4" ;
 		case FS_LINUX_SWAP	: return "linux-swap" ;
 		case FS_FAT16		: return "fat16" ;
 		case FS_FAT32		: return "fat32" ;
@@ -128,7 +137,9 @@ Glib::ustring Utils::get_filesystem_string( FILESYSTEM filesystem )
 		case FS_UFS		: return "ufs" ;
 		case FS_USED		: return _("used") ;
 		case FS_UNUSED		: return _("unused") ;
-					  
+		case FS_LVM2		: return "lvm2" ;
+		case FS_LUKS		: return "crypt-luks" ;
+
 		default			: return "" ;
 	}
 }
@@ -139,6 +150,7 @@ Glib::ustring Utils::get_filesystem_software( FILESYSTEM filesystem )
 	{
 		case FS_EXT2        : return "e2fsprogs" ;
 		case FS_EXT3        : return "e2fsprogs" ;
+		case FS_EXT4        : return "e2fsprogs v1.41+" ;
 		case FS_FAT16       : return "dosfstools, mtools" ;
 		case FS_FAT32       : return "dosfstools, mtools" ;
 		case FS_HFS         : return "hfsutils" ;
@@ -150,33 +162,32 @@ Glib::ustring Utils::get_filesystem_software( FILESYSTEM filesystem )
 		case FS_REISERFS    : return "reiserfsprogs" ;
 		case FS_UFS         : return "" ;
 		case FS_XFS         : return "xfsprogs" ;
-					  
+
 		default             : return "" ;
 	}
 }
 
-Glib::ustring Utils::format_size( Sector size ) 
+Glib::ustring Utils::format_size( Sector size )
 {
-	std::stringstream ss ;	
-	//ss .imbue( std::locale( "" ) ) ;  see #157871
+	std::stringstream ss ;
 	ss << std::setiosflags( std::ios::fixed ) << std::setprecision( 2 ) ;
-	
+
 	if ( size < KIBIBYTE )
 	{
 		ss << sector_to_unit( size, UNIT_BYTE ) ;
 		return String::ucompose( _("%1 B"), ss .str() ) ;
 	}
-	else if ( size < MEBIBYTE ) 
+	else if ( size < MEBIBYTE )
 	{
 		ss << sector_to_unit( size, UNIT_KIB ) ;
 		return String::ucompose( _("%1 KiB"), ss .str() ) ;
 	}
-	else if ( size < GIBIBYTE ) 
+	else if ( size < GIBIBYTE )
 	{
 		ss << sector_to_unit( size, UNIT_MIB ) ;
 		return String::ucompose( _("%1 MiB"), ss .str() ) ;
 	}
-	else if ( size < TEBIBYTE ) 
+	else if ( size < TEBIBYTE )
 	{
 		ss << sector_to_unit( size, UNIT_GIB ) ;
 		return String::ucompose( _("%1 GiB"), ss .str() ) ;
@@ -187,11 +198,11 @@ Glib::ustring Utils::format_size( Sector size )
 		return String::ucompose( _("%1 TiB"), ss .str() ) ;
 	}
 }
-	
-Glib::ustring Utils::format_time( std::time_t seconds ) 
+
+Glib::ustring Utils::format_time( std::time_t seconds )
 {
 	Glib::ustring time ;
-	
+
 	int unit = static_cast<int>( seconds / 3600 ) ;
 	if ( unit < 10 )
 		time += "0" ;
@@ -211,13 +222,13 @@ Glib::ustring Utils::format_time( std::time_t seconds )
 	return time ;
 }
 
-double Utils::sector_to_unit( Sector sectors, SIZE_UNIT size_unit ) 
+double Utils::sector_to_unit( Sector sectors, SIZE_UNIT size_unit )
 {
 	switch ( size_unit )
 	{
 		case UNIT_BYTE	:
 			return sectors * 512 ;
-		
+
 		case UNIT_KIB	:
 			return sectors / static_cast<double>( KIBIBYTE ) ;
 		case UNIT_MIB	:
@@ -226,13 +237,13 @@ double Utils::sector_to_unit( Sector sectors, SIZE_UNIT size_unit )
 			return sectors / static_cast<double>( GIBIBYTE ) ;
 		case UNIT_TIB	:
 			return sectors / static_cast<double>( TEBIBYTE ) ;
-		
+
 		default:
 			return sectors ;
 	}
 }
-	
-int Utils::execute_command( const Glib::ustring & command ) 
+
+int Utils::execute_command( const Glib::ustring & command )
 {
 	Glib::ustring dummy ;
 	return execute_command( command, dummy, dummy ) ;
@@ -245,7 +256,7 @@ int Utils::execute_command( const Glib::ustring & command,
 {
 	int exit_status = -1 ;
 	std::string std_out, std_error ;
-	
+
 	try
 	{
 		if ( use_C_locale )
@@ -258,20 +269,20 @@ int Utils::execute_command( const Glib::ustring & command,
 			argv .push_back( "-c" ) ;
 			argv .push_back( command ) ;
 
-			Glib::spawn_sync( ".", 
+			Glib::spawn_sync( ".",
 					  argv,
 					  envp,
 					  Glib::SPAWN_SEARCH_PATH,
 					  sigc::slot<void>(),
 					  &std_out,
-					  &std_error, 
+					  &std_error,
 					  &exit_status ) ;
 		}
 		else
 			Glib::spawn_command_line_sync( "sh -c '" + command + "'", &std_out, &std_error, &exit_status ) ;
 	}
 	catch ( Glib::Exception & e )
-	{ 
+	{
 		 error = e .what() ;
 
 		 return -1 ;
@@ -279,7 +290,7 @@ int Utils::execute_command( const Glib::ustring & command,
 
 	output = Utils::cleanup_cursor( std_out ) ;
 	error = std_error ;
-	
+
 	return exit_status ;
 }
 
@@ -288,7 +299,7 @@ Glib::ustring Utils::regexp_label( const Glib::ustring & text,
 {
 	//Extract text from a regular sub-expression.  E.g., "text we don't want (text we want)"
 	Glib::ustring label = "";
-	regex_t    preg ; 
+	regex_t    preg ;
 	int        nmatch = 2 ;
 	regmatch_t pmatch[  2 ] ;
 	int rc = regcomp( &preg, regular_sub_expression .c_str(), REG_EXTENDED | REG_ICASE | REG_NEWLINE ) ;
@@ -326,7 +337,7 @@ Glib::ustring Utils::create_mtoolsrc_file( char file_name[], const char drive_le
 		fcontents = String::ucompose(
 						"drive %1: file=\"%2\"\nmtools_skip_check=1\n", drive_letter, device_path
 					);
-		
+
 		if( write( fd, fcontents .c_str(), fcontents .size() ) == -1 ) {
 			err_msg = String::ucompose(
 							_("Label operation failed:  Unable to write to temporary file %1.\n")
@@ -374,7 +385,7 @@ Glib::ustring Utils::cleanup_cursor( const Glib::ustring & text )
 		else
 			str .erase( index, 1 ) ;
 	}
-	
+
 	//remove carriage return and line up to previous line feed.  Used in ntfsclone output.
 	//NOTE:  Normal linux line end is line feed.  DOS uses CR + LF.
 	for ( unsigned int index1 = str .find( "\r") ; index1 < str .length() ; index1 = str .find( "\r" ) ) {
@@ -399,10 +410,35 @@ Glib::ustring Utils::get_lang()
 	//Convert the underscore "_" to a hyphen "-"
 	Glib::ustring sought = "_" ;
 	Glib::ustring replacement = "-" ;
-	lang .replace( lang .find(sought), sought .size(), replacement ) ;
+	//NOTE:  Application crashes if string replace is called and sought is not found,
+	//       so we need to only perform replace if the sought is found.
+	if ( lang .find(sought) != Glib::ustring::npos )
+		lang .replace( lang .find(sought), sought .size(), replacement ) ;
 
 	return lang ;
 }
 
+//The tokenize method copied and adapted from:
+//  http://www.linuxselfhelp.com/HOWTO/C++Programming-HOWTO-7.html
+void Utils::tokenize( const Glib::ustring& str,
+                      std::vector<Glib::ustring>& tokens,
+                      const Glib::ustring& delimiters = " " )
+{
+	// Skip delimiters at beginning.
+	Glib::ustring::size_type lastPos = str.find_first_not_of(delimiters, 0);
+	// Find first "non-delimiter".
+	Glib::ustring::size_type pos     = str.find_first_of(delimiters, lastPos);
+
+	while (Glib::ustring::npos != pos || Glib::ustring::npos != lastPos)
+	{
+		// Found a token, add it to the vector.
+		tokens.push_back(str.substr(lastPos, pos - lastPos));
+		// Skip delimiters.  Note the "not_of"
+		lastPos = str.find_first_not_of(delimiters, pos);
+		// Find next "non-delimiter"
+		pos = str.find_first_of(delimiters, lastPos);
+	}
+}
+
 
 } //GParted..
