@@ -1,4 +1,5 @@
-/* Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009 Bart Hakvoort
+/* Copyright (C) 2004 Bart
+ * Copyright (C) 2008, 2009, 2010 Curtis Gedak
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -426,7 +427,7 @@ void Win_GParted::init_device_info()
 	
 	//title
 	vbox_info .pack_start( 
-		* Utils::mk_label( " <b>" + static_cast<Glib::ustring>( _("Device Information") ) + ":</b>" ),
+		* Utils::mk_label( " <b>" + static_cast<Glib::ustring>( _("Device Information") ) + "</b>" ),
 		Gtk::PACK_SHRINK );
 	
 	//GENERAL DEVICE INFO
@@ -471,7 +472,7 @@ void Win_GParted::init_device_info()
 	table ->attach( * Utils::mk_label( "" ), 1, 2, top++, bottom++, Gtk::FILL );
 	
 	//disktype
-	table ->attach( * Utils::mk_label( " <b>" + static_cast<Glib::ustring>( _("DiskLabelType:") ) + "</b>" ),
+	table ->attach( * Utils::mk_label( " <b>" + static_cast<Glib::ustring>( _("Partition table:") ) + "</b>" ),
 			0, 1,
 			top, bottom,
 			Gtk::FILL );
@@ -487,7 +488,7 @@ void Win_GParted::init_device_info()
 	table ->attach( * device_info .back(), 1, 2, top++, bottom++, Gtk::FILL ) ;
 	
 	//sectors/track
-	table ->attach( * Utils::mk_label( " <b>" + static_cast<Glib::ustring>( _("Sectors/Track:") ) + "</b>" ),
+	table ->attach( * Utils::mk_label( " <b>" + static_cast<Glib::ustring>( _("Sectors/track:") ) + "</b>" ),
 			0, 1,
 			top, bottom,
 			Gtk::FILL ) ;
@@ -503,7 +504,7 @@ void Win_GParted::init_device_info()
 	table ->attach( * device_info .back(), 1, 2, top++, bottom++, Gtk::FILL ) ;
 	
 	//total sectors
-	table ->attach( * Utils::mk_label( " <b>" + static_cast<Glib::ustring>( _("Total Sectors:") ) + "</b>" ),
+	table ->attach( * Utils::mk_label( " <b>" + static_cast<Glib::ustring>( _("Total sectors:") ) + "</b>" ),
 			0, 1,
 			top, bottom,
 			Gtk::FILL );
@@ -948,8 +949,7 @@ void Win_GParted::set_valid_operations()
 		if ( ! copied_partition .get_path() .empty() &&
 		     copied_partition .get_length() <= selected_partition .get_length() &&
 		     selected_partition .status == GParted::STAT_REAL &&
-		     copied_partition != selected_partition &&
-		     selected_partition .type == GParted::TYPE_UNALLOCATED )
+		     copied_partition != selected_partition )
 		     allow_paste( true ) ;
 
 		//see if we can somehow check/repair this file system....
@@ -1067,28 +1067,6 @@ void Win_GParted::menu_gparted_refresh_devices()
 	if ( current_device >= devices .size() )
 		current_device = 0 ;
 
-	//show read-only warning if necessary
-	std::vector<Glib::ustring> readonly_paths ;
-	for ( unsigned int t = 0 ; t < devices .size() ; t++ )
-		if ( devices[ t ] .readonly )
-			readonly_paths .push_back( "\n- " + devices[ t ] .get_path() ) ;
-		
-	if ( readonly_paths .size() > 0 )
-	{
-		Gtk::MessageDialog dialog(
-			*this,
-			_("The kernel is unable to re-read the partition tables on the following devices:") + 
-			Glib::build_path( "", readonly_paths ),
-			false,
-			Gtk::MESSAGE_WARNING,
-			Gtk::BUTTONS_OK,
-			true ) ;
-
-		dialog .set_secondary_text( _("Because of this you will only have limited access to these devices. Unmount all mounted partitions on a device to get full access.") ) ;
-		
-		dialog .run() ;
-	}
-	
 	//see if there are any pending operations on non-existent devices
 	//NOTE that this isn't 100% foolproof since some stuff (e.g. sourcedevice of copy) may slip through.
 	//but anyone who removes the sourcedevice before applying the operations gets what he/she deserves :-)
@@ -1204,53 +1182,82 @@ void Win_GParted::menu_view_operations()
 		close_operationslist() ;
 }
 
-void Win_GParted::show_help_dialog (const char *link_id /* For context sensitive help */)
+void Win_GParted::show_disklabel_unrecognized ( Glib::ustring device_name )
 {
-/* Original concept for show_help_dialog is from file-roller project
- * gtk-utils.c revision 1967, Tue Aug 7 06:18:42 2007 UTC
- * See http://fileroller.sourceforge.net/
- * 
- * Modified to work with GParted by Curtis Gedak :-)
- */
-	GError *err = NULL;
-	char *command;
-	const char *lang;
-	char *uri = NULL;
-	int i;
-	GdkScreen *gscreen;
+	//Display dialog box indicating that no partition table was found on the device
+	Gtk::MessageDialog dialog( *this,
+			/*TO TRANSLATORS: looks like   No partition table found on device /dev/sda */
+			String::ucompose( _( "No partition table found on device %1" ), device_name ),
+			false,
+			Gtk::MESSAGE_INFO,
+			Gtk::BUTTONS_OK,
+			true ) ;
+	Glib::ustring tmp_msg = _( "A partition table is required before partitions can be added." ) ;
+	tmp_msg += "\n" ;
+	tmp_msg += _( "To create a new partition table choose the menu item:" ) ;
+	tmp_msg += "\n" ;
+	/*TO TRANSLATORS: this message represents the menu item Create Partition Table under the Device menu. */
+	tmp_msg += _( "Device --> Create Partition Table." ) ;
+	dialog .set_secondary_text( tmp_msg ) ;
+	dialog .run() ;
+}
 
-	const char * const * langs = g_get_language_names ();
+void Win_GParted::show_help_dialog( const Glib::ustring & filename /* E.g., gparted */
+                                  , const Glib::ustring & link_id  /* For context sensitive help */
+                                  )
+{
+	GError *error = NULL ;
+	GdkScreen *gscreen = NULL ;
 
-	for (i = 0; langs[i]; i++) {
-		lang = langs[i];
-		if (strchr (lang, '.')) {
-			continue;
-		}
-
-		uri = g_build_filename( GPARTED_DATADIR,
-								"/gnome/help/gparted/",
-								lang,
-								"/gparted.xml",
-								NULL );
-					
-		if (g_file_test (uri, G_FILE_TEST_EXISTS)) {
-                    break;
-		}
-	}
-	
-	if (link_id) {
-		command = g_strconcat ("gnome-open ghelp://", uri, "?", link_id, NULL);
-	} else {
-		command = g_strconcat ("gnome-open ghelp://", uri,  NULL);
+	Glib::ustring uri = "ghelp:" + filename ;
+	if (link_id .size() > 0 ) {
+		uri = uri + "?" + link_id ;
 	}
 
-	gscreen = gdk_screen_get_default();
-	gdk_spawn_command_line_on_screen (gscreen, command, &err);
+	gscreen = gdk_screen_get_default() ;
+
+#ifdef HAVE_GTK_SHOW_URI
+	gtk_show_uri( gscreen, uri .c_str(), gtk_get_current_event_time(), &error ) ;
+#else
+	Glib::ustring command = "gnome-open " + uri ;
+	gdk_spawn_command_line_on_screen( gscreen, command .c_str(), &error ) ;
+#endif
+
+	if ( error != NULL )
+	{
+		Gtk::MessageDialog dialog( *this
+		                         , _( "Unable to open GParted Manual help file." )
+		                         , false
+		                         , Gtk::MESSAGE_ERROR
+		                         , Gtk::BUTTONS_OK
+		                         , true
+		                         ) ;
+		dialog .set_secondary_text( error ->message ) ;
+		dialog .run() ;
+	}
 }
 
 void Win_GParted::menu_help_contents()
 {
-	show_help_dialog( NULL);
+#ifdef HAVE_DISABLE_DOC
+	//GParted was configured with --disable-doc
+	Gtk::MessageDialog dialog( *this,
+			_( "Documentation is not available." ),
+			false,
+			Gtk::MESSAGE_INFO,
+			Gtk::BUTTONS_OK,
+			true ) ;
+	Glib::ustring tmp_msg = _( "This build of gparted is configured without documentation." ) ;
+	tmp_msg += "\n" ;
+	tmp_msg += _( "Documentation is available at the project web site." ) ;
+	tmp_msg += "\n" ;
+	tmp_msg += "http://gparted.sourceforge.net" ;
+	dialog .set_secondary_text( tmp_msg ) ;
+	dialog .run() ;
+#else
+	//GParted was configured without --disable-doc
+	show_help_dialog( "gparted", "" );
+#endif
 }
 
 void Win_GParted::menu_help_about()
@@ -1264,7 +1271,7 @@ void Win_GParted::menu_help_about()
 	dialog .set_logo_icon_name( "gparted" ) ;
 	dialog .set_version( VERSION ) ;
 	dialog .set_comments( _( "GNOME Partition Editor" ) ) ;
-	dialog .set_copyright( "Copyright © 2004-2009 Bart Hakvoort" ) ;
+	dialog .set_copyright( "Copyright © 2004-2006 Bart Hakvoort\nCopyright © 2008-2010 Curtis Gedak" ) ;
 
 	//authors
 	strings .push_back( "Bart Hakvoort <gparted@users.sf.net>" ) ;
@@ -1417,9 +1424,7 @@ void Win_GParted::activate_paste()
 	//if max_prims == -1 the current device has an unrecognised disklabel (see also GParted_Core::get_devices)
 	if ( devices [ current_device ] .max_prims == -1 )
 	{
-		//FIXME: actually we should proceed with pasting after the new disklabel is set.
-		//(the same goes when creating a new partition on a disk without disklabel)
-		activate_disklabel() ;
+		show_disklabel_unrecognized( devices [current_device ] .get_path() ) ;
 		return ;
 	}
 
@@ -1465,6 +1470,18 @@ void Win_GParted::activate_paste()
 		operation ->icon = render_icon( Gtk::Stock::COPY, Gtk::ICON_SIZE_MENU );
 
 		Add_Operation( operation ) ;
+
+		//Warn that paste operation will overwrite data in existing partition
+		Gtk::MessageDialog dialog( *this
+		                         , _( "You have pasted into an existing partition." )
+		                         , false
+		                         , Gtk::MESSAGE_WARNING
+		                         , Gtk::BUTTONS_OK
+		                         , true
+		                         ) ;
+		/*TO TRANSLATORS: looks like   The data in /dev/sda3 will be lost if you apply this operation. */
+		dialog .set_secondary_text( String::ucompose( _( "The data in %1 will be lost if you apply this operation."), partition_new .get_path() ) ) ;
+		dialog .run() ;
 	}
 }
 
@@ -1472,8 +1489,9 @@ void Win_GParted::activate_new()
 {
 	//if max_prims == -1 the current device has an unrecognised disklabel (see also GParted_Core::get_devices)
 	if ( devices [ current_device ] .max_prims == -1 )
-		activate_disklabel() ;
-			
+	{
+		show_disklabel_unrecognized( devices [current_device ] .get_path() ) ;
+	}
 	else if ( ! max_amount_prim_reached() )
 	{	
 		Dialog_Partition_New dialog;
@@ -1843,6 +1861,34 @@ void Win_GParted::activate_mount_partition( unsigned int index )
 
 void Win_GParted::activate_disklabel()
 {
+	//If there are pending operations then warn the user that these
+	//  operations must either be applied or cleared before creating
+	//  a new partition table.
+	if ( operations .size() )
+	{
+		Glib::ustring tmp_msg =
+		    String::ucompose( ngettext( "%1 operation is currently pending."
+		                              , "%1 operations are currently pending."
+		                              , operations .size()
+		                              )
+		                    , operations .size()
+		                    ) ;
+		Gtk::MessageDialog dialog( *this
+		                         , tmp_msg
+		                         , false
+		                         , Gtk::MESSAGE_INFO
+		                         , Gtk::BUTTONS_OK
+		                         , true
+		                         ) ;
+		tmp_msg  = _( "A new partition table cannot be created when there are pending operations." ) ;
+		tmp_msg += "\n" ;
+		tmp_msg += _( "Use the Edit menu to either clear or apply all operations before creating a new partition table." ) ;
+		dialog .set_secondary_text( tmp_msg ) ;
+		dialog .run() ;
+		return ;
+	}
+
+	//Display dialog for creating a new partition table.
 	Dialog_Disklabel dialog( devices[ current_device ] .get_path(), gparted_core .get_disklabeltypes() ) ;
 	dialog .set_transient_for( *this );
 
